@@ -22,10 +22,10 @@ def generate_jwt(claims, priv_key=None,
     :param claims: The claims you want included in the signature.
     :type claims: dict
 
-    :param priv_key: The private key to be used to sign the token. Note: if you pass :obj:`None` then the token will be returned with an invalid cryptographic signature (it will have the value ```*```). Use :obj:`None` when you're not using a public key infrastructure to authenticate your data.
+    :param priv_key: The private key to be used to sign the token. Note: if you pass :obj:`None` then the token will be returned with an empty cryptographic signature and :obj:`algorithm` will be forced to the value ``none``.
     :type priv_key: `_RSAobj <https://www.dlitz.net/software/pycrypto/api/current/Crypto.PublicKey.RSA._RSAobj-class.html>`_, `SigningKey <https://github.com/warner/python-ecdsa>`_ or str
 
-    :param algorithm: The algorithm to use for generating the signature. ``RS256``, ``RS384``, ``RS512``, ``PS256``, ``PS384``, ``PS512``, ``ES256``, ``ES384``, ``ES512``, ``HS256``, ``HS384`` and ``HS512`` are supported.
+    :param algorithm: The algorithm to use for generating the signature. ``RS256``, ``RS384``, ``RS512``, ``PS256``, ``PS384``, ``PS512``, ``ES256``, ``ES384``, ``ES512``, ``HS256``, ``HS384``, ``HS512`` and ``none`` are supported.
     :type algorithm: str
 
     :param lifetime: How long the token is valid for.
@@ -47,7 +47,7 @@ def generate_jwt(claims, priv_key=None,
     """
     header = {
         'typ': 'JWT',
-        'alg': algorithm
+        'alg': algorithm if priv_key else 'none'
     }
 
     claims = dict(claims)
@@ -66,7 +66,7 @@ def generate_jwt(claims, priv_key=None,
     return "%s.%s.%s" % (
         jws.utils.encode(header),
         jws.utils.encode(claims),
-        jws.sign(header, claims, priv_key) if priv_key else '*'
+        '' if header['alg'] == 'none' else jws.sign(header, claims, priv_key)
     )
 
 def verify_jwt(jwt, pub_key=None, iat_skew=timedelta()):
@@ -85,7 +85,7 @@ def verify_jwt(jwt, pub_key=None, iat_skew=timedelta()):
     :rtype: tuple
     :returns: ``(header, claims)`` if the token was verified successfully. The token must pass the following tests:
 
-    - Its signature must verify using the public key.
+    - Its signature must verify using the public key or its algorithm must be ``none``.
     - Its header must contain a property **typ** with the value ``JWT``.
     - Its claims must contain a property **iat** which represents a date in the past (taking into account :obj:`iat_skew`).
     - Its claims must contian a property **nbf** which represents a date in the past.
@@ -96,12 +96,13 @@ def verify_jwt(jwt, pub_key=None, iat_skew=timedelta()):
     header, claims, sig = jwt.split('.')
 
     header = jws.utils.from_base64(header)
+    parsed_header = jws.utils.from_json(header)
     claims = jws.utils.from_base64(claims)
 
-    if pub_key:
+    if pub_key and parsed_header['alg'] != 'none':
         jws.verify(header, claims, sig, pub_key, True)
 
-    header = jws.utils.from_json(header)
+    header = parsed_header
     claims = jws.utils.from_json(claims)
 
     utcnow = datetime.utcnow()
